@@ -198,6 +198,7 @@ class Trainer:
             cache_dir=self.arguments.cache_dir,
             gradient_checkpointing=self.arguments.gradient_checkpointing,
             dropout_rate=self.arguments.dropout_rate,
+            use_cache=not self.arguments.gradient_checkpointing
         )
         self.tokenizer = AutoTokenizer.from_pretrained(
             self.arguments.model_name_or_path,
@@ -215,7 +216,9 @@ class Trainer:
             total_num_layers = self.config.num_layers
             layer_per_gpu = total_num_layers // self.arguments.model_parallel_gpus
             for i in range(self.arguments.model_parallel_gpus):
-                device_map[i] = list(range(i*6, (i+1)*6))
+                layers = list(range(i*layer_per_gpu, (i+1)*layer_per_gpu))
+                device_map[i] = layers
+                print("Place layers", layers, "on device", i)
             self.model.parallelize(device_map)
         self.padding = "max_length" if self.arguments.pad_to_max_length else False
 
